#!/usr/bin/env python

import numpy as np
import argparse
from astropy.io import fits

def mkmask(infile):
    coos = np.loadtxt(infile, dtype=np.int)
    fid = infile[:12]
    data = fits.getdata(fid+'.cr.fits')
    outdata = np.zeros(data.shape, dtype=np.uint8)
    for coo  in coos:
        outdata[coo[1]-1, coo[0]-1] = 1

    # Writing the output file
    outhdu = fits.PrimaryHDU(outdata)
    outhdl = fits.HDUList([outhdu])
    outhdl.writeto(fid+'.mask2.fits')
    outhdl.close()
        
    return


if __name__ == '__main__':
    parser=argparse.ArgumentParser(
        description='This is the script for creating a mask FITS file'+
        ' from a coordinate list.')
    parser.add_argument('infile',
                        help='Input file contaning pixel coordinates.')
    args = parser.parse_args()

    mkmask(args.infile)
