#!/usr/bin/env python
# python3 OK

import sys
from astropy.io import fits
import subprocess
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.colors import LogNorm
from rmidpoints import ReadIDFile

def plot_position(basenames):
    for i in range(len(basenames)):
        data = fits.getdata(basenames[i]+'.fits')
        coo = ReadIDFile('database/id' + basenames[i])
        coo_np = np.array(coo)
        ax[i,0].imshow(data, origin='bottom', aspect='auto',
                   norm=LogNorm(vmin=1,vmax=np.max(data)))
        ax[i,0].scatter(coo_np[:,0], coo_np[:,1] , s=5, c='red')
        ax[i,0].set_xlabel('X (pix)')
        ax[i,0].set_ylabel('Y (pix)')
        ax[i,0].set_title(basenames[i])

    plt.tight_layout()
    plt.draw()
    plt.pause(0.01)
    return


if sys.version_info[0] == 3:
    st = input()
else:
    st = raw_input()

print("plot_position.py: ", st)
basenames = st.split(',')

fig, ax = plt.subplots(1, len(basenames),figsize=(5*len(basenames), 8),
                       squeeze=False)

while(st is not 'q'):
    plot_position(basenames)
    if sys.version_info[0] == 3:
        st = input()
    else:
        st = raw_input()

    basenames = st.split(',')
