#!/usr/bin/env python3
# python3 OK

from astropy.io import fits
import argparse


def wtrim(infile, outfile, w1=None, w2=None, overwrite=False):
    hdl = fits.open(infile)
    hdr = hdl[0].header
    data = hdl[0].data
    binfct1 = hdr['BIN-FCT1']
    disperser = hdr['DISPERSR']
    filter1 = hdr['FILTER01']
    filter2 = hdr['FILTER02']
    filter3 = hdr['FILTER03']
    crpix = hdr['CRPIX3']
    crval = hdr['CRVAL3']
    cdelt = hdr['CD3_3']

    # 300R + SO58
    if disperser == 'SCFCGRMR01' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSO58' and filter3 == 'NONE':
        y1 = 5800.
        y2 = 9550.
    
    # 300R + L600
    elif disperser == 'SCFCGRMR01' and filter1 == 'SCFCFLL600' and \
       filter2 == 'NONE' and filter3 == 'NONE':
        y1 = 3700.
        y2 = 4900.
        
    # 300B+SY47
    elif disperser == 'SCFCGRMB01' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSY47' and filter3 == 'NONE':
        y1 = 4700.
        y2 = 7600.
        
    # 300B + NONE
    elif disperser == 'SCFCGRMB01' and filter1 == 'NONE' and \
       filter2 == 'NONE' and filter3 == 'NONE':
        y1 = 3700.
        y2 = 6000.

    # VPH850 + SO58
    elif disperser == 'SCFCGRHD85' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSO58' and filter3 == 'NONE':
        y1 = 6050.
        y2 = 9750.

    # VPH520
    elif disperser == 'SCFCGRHD52' and filter1 == 'NONE' and \
       filter2 == 'NONE' and filter3 == 'NONE':
        y1 = 4540.
        y2 = 5830.

    # VPH650+SY47
    elif disperser == 'SCFCGRHD65' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSY47' and filter3 == 'NONE':
        y1 = 5600.0
        y2 = 7200.0
        
    # VPH900 + SO58
    elif disperser == 'SCFCGRHD90' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSO58' and filter3 == 'NONE':
        y1 = 7850.
        y2 = 9950.

    # VPH680 + SY47
    elif disperser == 'SCFCGRHD68' and filter1 == 'NONE' and \
       filter2 == 'SCFCFLSY47' and filter3 == 'NONE':
        y1 = 6510.0
        y2 = 7320.0

    if w1 is not None:
        y1 = w1
    if w2 is not None:
        y2 = w2
    
    p1 = int((y1 - crval) / cdelt + crpix -1 + 0.5)
    p2 = int((y2 - crval) / cdelt + crpix -1 + 0.5)
    hdr['CRPIX3'] = 1
    hdr['CRVAL3'] = crval + (p1 - crpix + 1) * cdelt

    # Writing the output file
    outhdu = fits.PrimaryHDU(data[p1:p2+1])
    outhdl = fits.HDUList([outhdu])
    outhdl[0].header = hdr
    outhdl.writeto(outfile, overwrite=overwrite)
    outhdl.close()
    hdl.close()
    print('\t Wavelength ragen was trimed: {} to {}.'.format(y1,y2))
    print('\t Output file: '+outfile)
    return outfile, True
        
if __name__ == '__main__':
    parser=argparse.ArgumentParser(description='This is the '+\
            'script for triming the wavelength range of a data cube.')
    parser.add_argument('-o', help='Overwrite flag', dest='overwrite',\
            action='store_true',default=False)
    parser.add_argument('infile', help='Input FITS file.')
    parser.add_argument('outfile', help='Output FITS file.')
    parser.add_argument('-w1', help='Start wavelength (A)', default=None,
                        type=float)    
    parser.add_argument('-w2', help='End wavelength (A)', default=None,
                        type=float)    
    args = parser.parse_args()

    wtrim(args.infile, args.outfile, w1=args.w1, w2=args.w2, overwrite=args.overwrite)
